pub struct TestFixture {
pub realm: RealmInstance,
pub ramdisks: Vec<RamdiskClient>,
pub main_disk: Option<Disk>,
pub crash_reports: Receiver<CrashReport>,
/* private fields */
}Fields
realm: RealmInstanceramdisks: Vec<RamdiskClient>main_disk: Option<Disk>crash_reports: Receiver<CrashReport>Implementations
Sourceimpl TestFixture
impl TestFixture
pub async fn tear_down(self) -> Option<Disk>
pub fn exposed_dir(&self) -> &DirectoryProxy
pub fn dir(&self, dir: &str, flags: Flags) -> DirectoryProxy
pub async fn check_fs_type(&self, dir: &str, fs_type: u32)
pub async fn check_test_blob(&self)
Sourcepub async fn check_test_data_file(&self)
pub async fn check_test_data_file(&self)
Check for the existence of a well-known set of test files in the data volume. These files are placed by the disk builder if it formats the filesystem beforehand.
Sourcepub async fn check_test_data_file_absent(&self)
pub async fn check_test_data_file_absent(&self)
Checks for the absence of the .testdata marker file, indicating the data filesystem was reformatted.
pub async fn add_main_disk(&mut self, disk: Disk)
pub async fn add_disk(&mut self, disk: Disk)
pub fn connect_to_crypt(&self) -> CryptProxy
pub async fn setup_starnix_crypt(&self) -> (CryptProxy, CryptManagementProxy)
Sourcepub async fn wait_for_crash_reports(
&mut self,
count: usize,
expected_program: &str,
expected_signature: &str,
)
pub async fn wait_for_crash_reports( &mut self, count: usize, expected_program: &str, expected_signature: &str, )
This must be called if any crash reports are expected, since spurious reports will cause a failure in TestFixture::tear_down.
pub async fn check_system_partitions(&self, expected: Vec<&str>)